@@ -1,7 +1,8 @@
 package Mojo::ByteStream;
-use Mojo::Base 'Exporter';
+use Mojo::Base -base;
 use overload '""' => sub { shift->to_string }, fallback => 1;
 
+use Exporter 'import';
 use Mojo::Collection;
 use Mojo::Util;
 
@@ -11,8 +12,8 @@ our @EXPORT_OK = ('b');
 my @UTILS = (
   qw(b64_decode b64_encode camelize decamelize hmac_md5_sum hmac_sha1_sum),
   qw(html_escape html_unescape md5_bytes md5_sum punycode_decode),
-  qw(punycode_encode quote sha1_bytes sha1_sum slurp spurt trim unquote),
-  qw(url_escape url_unescape xml_escape)
+  qw(punycode_encode quote sha1_bytes sha1_sum slurp spurt squish trim),
+  qw(unquote url_escape url_unescape xml_escape)
 );
 {
   no strict 'refs';
@@ -117,13 +118,14 @@ Construct a new L<Mojo::ByteStream> object.
 
 =head1 METHODS
 
-L<Mojo::ByteStream> implements the following methods.
+L<Mojo::ByteStream> inherits all methods from L<Mojo::Base> and implements the
+following new ones.
 
 =head2 C<new>
 
   my $stream = Mojo::ByteStream->new('test123');
 
-Construct a new L<Mojo::ByteStream> object.
+Construct a new scalar-based L<Mojo::ByteStream> object.
 
 =head2 C<b64_decode>
 
@@ -294,6 +296,14 @@ Turn bytestream into L<Mojo::Collection>.
 
   b('a,b,c')->split(',')->pluck('quote')->join(',')->say;
 
+=head2 C<squish>
+
+  $stream = $stream->squish;
+
+Trim whitespace characters from both ends of bytestream and then change all
+consecutive groups of whitespace into one space each with
+L<Mojo::Util/"squish">.
+
 =head2 C<to_string>
 
   my $string = $stream->to_string;
