@@ -70,12 +70,12 @@ sub client {
 }
 
 sub delay {
-  my ($self, $cb) = @_;
+  my $self = shift;
   $self = $self->singleton unless ref $self;
 
   my $delay = Mojo::IOLoop::Delay->new;
   weaken $delay->ioloop($self)->{ioloop};
-  $delay->once(finish => $cb) if $cb;
+  @_ > 1 ? $delay->steps(@_) : $delay->once(finish => shift) if @_;
 
   return $delay;
 }
@@ -443,9 +443,11 @@ L<Mojo::IOLoop::Client/"connect">.
   my $delay = Mojo::IOLoop->delay;
   my $delay = $loop->delay;
   my $delay = $loop->delay(sub {...});
+  my $delay = $loop->delay(sub {...}, sub {...});
 
-Get L<Mojo::IOLoop::Delay> object to synchronize events and subscribe to event
-L<Mojo::IOLoop::Delay/"finish"> if optional callback is provided.
+Get L<Mojo::IOLoop::Delay> object to control the flow of events. A single
+callback will be treated as a subscriber to the C<finish> event, and multiple
+ones as a chain of steps.
 
   # Synchronize multiple events
   my $delay = Mojo::IOLoop->delay(sub { say 'BOOM!' });
@@ -457,6 +459,28 @@ L<Mojo::IOLoop::Delay/"finish"> if optional callback is provided.
     });
   }
 
+  # Sequentialize multiple events
+  my $delay = Mojo::IOLoop->delay(
+
+    # First step (simple timer)
+    sub {
+      my $delay = shift;
+      Mojo::IOLoop->timer(2 => $delay->begin);
+      say 'Second step in 2 seconds.';
+    },
+
+    # Second step (parallel timers)
+    sub {
+      my $delay = shift;
+      Mojo::IOLoop->timer(1 => $delay->begin);
+      Mojo::IOLoop->timer(3 => $delay->begin);
+      say 'Third step in 3 seconds.';
+    },
+
+    # Third step (the end)
+    sub { say 'And done after 5 seconds total.' }
+  );
+
   # Wait for events if necessary
   $delay->wait unless Mojo::IOLoop->is_running;
 
