@@ -6,10 +6,9 @@ use Fcntl ':flock';
 
 # "Would you kindly shut your noise-hole?"
 has handle => sub {
-  my $self = shift;
 
   # File
-  if (my $path = $self->path) {
+  if (my $path = shift->path) {
     croak qq{Can't open log file "$path": $!}
       unless open my $file, '>>:utf8', $path;
     return $file;
@@ -58,21 +57,20 @@ sub is_warn { shift->is_level('warn') }
 
 # "If The Flintstones has taught us anything,
 #  it's that pelicans can be used to mix cement."
-sub log {
-  my $self  = shift;
-  my $level = lc shift;
-  return $self unless $self->is_level($level);
-  return $self->emit(message => $level => @_);
-}
+sub log { shift->emit('message', lc(shift), @_) }
 
 sub warn { shift->log(warn => @_) }
 
 sub _message {
-  my $self = shift;
-  return unless my $handle = $self->handle;
+  my ($self, $level, @lines) = @_;
+
+  # Check level
+  return unless $self->is_level($level) && (my $handle = $self->handle);
+
+  # Format lines and write to handle
   flock $handle, LOCK_EX;
   croak "Can't write to log: $!"
-    unless defined $handle->syswrite($self->format(@_));
+    unless defined $handle->syswrite($self->format($level, @lines));
   flock $handle, LOCK_UN;
 }
 
