@@ -32,8 +32,7 @@ get '/echo' => sub {
 # GET /stream
 get '/stream' => sub {
   shift->write_chunk(
-    'he',
-    sub {
+    'he' => sub {
       shift->write_chunk('ll' => sub { shift->finish('o!') });
     }
   );
