@@ -5,16 +5,16 @@ use Mojo::Base 'Mojolicious::Plugin';
 #  I've performed a few mercy killings."
 sub register {
   my ($self, $app) = @_;
-  $app->routes->route('/foo')->detour(PluginWithEmbeddedApp::App::app());
+  $app->routes->route('/plugin')->detour(PluginWithEmbeddedApp::App::app());
 }
 
 package PluginWithEmbeddedApp::App;
 use Mojolicious::Lite;
 
-# GET /bar
-get '/bar';
+# GET /foo
+get '/foo';
 
 1;
 __DATA__
-@@ bar.html.ep
+@@ foo.html.ep
 plugin works!\
